pub struct AddrInfoHints {
pub flags: i32,
pub address: i32,
pub socktype: i32,
pub protocol: i32,
}Expand description
A struct used as the hints argument to getaddrinfo.
Fields
flags: i32Optional bitmask arguments. Bitwise OR bitflags to change the
behaviour of getaddrinfo. 0 for none. ai_flags in libc.
Values are defined by the libc on your system.
address: i32Address family for this socket. 0 for none. ai_family in libc.
Values are defined by the libc on your system.
socktype: i32Type of this socket. 0 for none. ai_socktype in libc.
Values are defined by the libc on your system.
protocol: i32Protcol for this socket. 0 for none. ai_protocol in libc.
Values are defined by the libc on your system.